#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Nov 19 14:00:53 2017

@author: stella
"""

import pandas as pd
import codecs
from bokeh.charts import Scatter
from bokeh.plotting import output_file,show,figure

with codecs.open("albumlist.csv", "r", "ASCII", "ignore") as file:
    a_list = pd.read_table(file, delimiter=",")
a_list.head()

for lab, row in a_list.iterrows():
    a_list.loc[lab, "Genre_Refined"] = row["Genre"].split(',')[0]
    a_list.loc[lab, "Subgenre_Refined"] = row["Subgenre"].split(',')[0]
a_list.head()

# VIS 1
artists_count = a_list.groupby(['Artist'], as_index=False).count()
top_artists = artists_count.sort_values(by='Number', ascending=False).head(5)
top_artists = top_artists.reset_index().drop(['index', 'Album','Year','Genre','Subgenre', 'Genre_Refined', 'Subgenre_Refined'], axis=1)
top_artists_list = top_artists.Artist.values.tolist()
top_artists_count = top_artists.Number.astype(float).values.tolist()

output_file("top_artists.html",title = "Top 5 Rock Artists")
p = figure(x_range=top_artists_list, plot_height = 500, plot_width = 500)

p.xgrid.visible = False
p.xaxis.major_label_orientation = 3.14/4
p.xaxis.axis_label = 'Artist Name'
p.ygrid.visible = False
p.yaxis.axis_label = 'Album Count'
p.circle(y=top_artists_count, x=top_artists_list, size=20, fill_color="navy",alpha=0.5)
show(p)

# VIS 2
yearwise_subgenres = a_list.groupby(['Year', 'Genre_Refined', 'Subgenre_Refined'], as_index=False).count()
rock_subgenres_yearwise = yearwise_subgenres[yearwise_subgenres['Genre_Refined'] == 'Rock'].reset_index().drop(['index', 'Album', 'Artist','Genre','Subgenre'], axis=1)
rock_subgenres_yearwise.head()
output_file("subgenres_rock.html",title = "Subgenres_rock")

hm_rock_subgenres = Scatter(rock_subgenres_yearwise, x='Year', y='Subgenre_Refined', width=800, plot_height=800)

hm_rock_subgenres.xgrid.visible = False
hm_rock_subgenres.yaxis.major_label_orientation = 'horizontal'
hm_rock_subgenres.yaxis.axis_label = 'Subgenres of Rock'
hm_rock_subgenres.ygrid.visible = False
show(hm_rock_subgenres)



































